@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 #
-# Copyright (C) 2014  Ruby-GNOME2 Project Team
+# Copyright (C) 2014-2019  Ruby-GNOME Project Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -36,7 +36,7 @@ $LOAD_PATH.unshift(mkmf_gnome2_dir.to_s)
 module_name = "gio2"
 package_id = "gio-2.0"
 
-require "mkmf-gnome2"
+require "mkmf-gnome"
 
 ["glib2", "gobject-introspection"].each do |package|
   directory = "#{package}#{version_suffix}"
@@ -52,7 +52,7 @@ end
 unless required_pkg_config_package(package_id,
                                    :alt_linux => "libgio-devel",
                                    :debian => "libglib2.0-dev",
-                                   :redhat => "glib2-devel",
+                                   :redhat => "pkgconfig(#{package_id})",
                                    :arch_linux => "glib2",
                                    :homebrew => "glib",
                                    :macports => "glib2")
